# `narwhals.Expr.dt`

::: narwhals.expression.ExprDateTimeNamespace
    handler: python
    options:
      members:
        - year
        - month
        - day
        - ordinal_day
        - hour
        - minute
        - second
        - millisecond
        - microsecond
        - nanosecond
        - total_minutes
        - total_seconds
        - total_milliseconds
        - total_microseconds
        - total_nanoseconds
      show_source: false
      show_bases: false
